aboutsummaryrefslogtreecommitdiff
path: root/arch/x86_64/include
diff options
context:
space:
mode:
Diffstat (limited to 'arch/x86_64/include')
-rw-r--r--arch/x86_64/include/arch/kernel/cpu/call.hpp (renamed from arch/x86_64/include/arch/kernel/cpu/jmp.hpp)17
1 files changed, 5 insertions, 12 deletions
diff --git a/arch/x86_64/include/arch/kernel/cpu/jmp.hpp b/arch/x86_64/include/arch/kernel/cpu/call.hpp
index 1657c18..3c43304 100644
--- a/arch/x86_64/include/arch/kernel/cpu/jmp.hpp
+++ b/arch/x86_64/include/arch/kernel/cpu/call.hpp
@@ -8,29 +8,22 @@
namespace teachos::arch::kernel::cpu
{
/**
- * @brief Far jump - A jump to an instruction located in a different segment.
+ * @brief Far Pointer. Address to function located in another code segment.
*/
struct far_pointer
{
- void (*function)(); ///< Address of the function we want to jump too. (0-63)
+ void (*function)(); ///< Address of the function we want to call. (0-63)
context_switching::interrupt_descriptor_table::segment_selector
selector; ///< Segment selector pointing to the GDT entry we want to load into register CS. (64-79)
};
/**
- * @brief Near jump - A jump to an instruction within the current code segment.
- *
- * @param address Address we want to jump to.
- */
- auto jmp(std::size_t address) -> void;
-
- /**
- * @brief Far jump - A jump to an instruction located in a different segment than the current code segment but at the
+ * @brief Far call - A call to an instruction located in a different segment than the current code segment but at the
* same privilege level.
*
* @param pointer 64-bit operand size far pointer that we should jump too.
*/
- auto jmp(far_pointer pointer) -> void;
+ auto call(far_pointer pointer) -> void;
} // namespace teachos::arch::kernel::cpu
@@ -8,29 +8,22 @@
* same privilege level.
*
- * @param pointer 64-bit operand size far pointer that we should jump too.
+ * @param pointer 64-bit operand size far pointer that we want to call.
*/